#!/bin/bash

# abort the script on any error:
set -e

# echo the commands:
# set -x

APPNAME="PTGui"
VIEWERNAME="PTGui Viewer"
INSTALLDIR=/opt/ptgui

# get directory of current script
SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )

if [ "$EUID" -ne 0 ]
  then echo "Please run as root (sudo)."
  exit 1
fi

if [ ! -f "${SCRIPT_DIR}/PTGui" ]
  then echo "File not found: ${SCRIPT_DIR}/PTGui"
  exit 2
fi

echo "This will install ${APPNAME} into ${INSTALLDIR}/"
echo "File types will be registered and ${APPNAME} will be added to the desktop."
echo ""
read -p "Press Enter to continue, Ctrl+C to abort:"

mkdir -p "${INSTALLDIR}"

cp -a "${SCRIPT_DIR}"/* "${INSTALLDIR}/"
chown -R root:root "${INSTALLDIR}/"

TMPDIR="/tmp/ptguiinstall_d78"
rm -rf "${TMPDIR}"
mkdir "${TMPDIR}"

cat << EOF > "${TMPDIR}/newhouse-ptgui.desktop"
[Desktop Entry]
Name=${APPNAME}
Comment=PTGui Stitching Software
Keywords=panorama;stitching;stich;stitcher;panoramas;
Exec=env GDK_BACKEND=x11 "${INSTALLDIR}/PTGui" %F
Icon=${INSTALLDIR}/ptgui_icon.png
Terminal=false
Type=Application
Categories=Graphics
MimeType=application/x-ptguiproject;application/x-ptguibatchlist;image/tiff;image/jpeg;image/png;image/x-exr;image/x-canon-crw;image/x-canon-cr2;image/x-canon-cr3;image/x-nikon-nef;image/x-fuji-raf;image/x-sigma-x3f;image/x-minolta-mrw;image/x-sony-srf;image/x-adobe-dng;image/x-olympus-orf;image/x-sony-arw;image/x-pentax-pef;image/x-kodak-dcr;image/x-sony-sr2;image/x-gopro-gpr;image/x-panasonic-raw
EOF

cat << EOF > "${TMPDIR}/newhouse-ptguiviewer.desktop"
[Desktop Entry]
Name=${VIEWERNAME}
Comment=Viewer for spherical panoramas
Keywords=panorama;panoramas;viewer;PTGui;
Exec="${INSTALLDIR}/PTGuiViewer" %F
Icon=${INSTALLDIR}/ptguiviewer_icon.png
Terminal=false
Type=Application
StartupNotify=false
Categories=Graphics
MimeType=image/tiff;image/jpeg;image/png;image/x-exr
EOF

cat << EOF > "${TMPDIR}/newhouse-ptguimimetypes.xml"
<?xml version="1.0"?>
<mime-info xmlns='http://www.freedesktop.org/standards/shared-mime-info'>
  <mime-type type="application/x-ptguiproject">
    <comment>PTGui project file</comment>
    <glob pattern="*.pts"/>
  </mime-type>
  <mime-type type="application/x-ptguibatchlist">
    <comment>PTGui batch list</comment>
    <glob pattern="*.ptgbatch"/>
  </mime-type>
</mime-info>
EOF

xdg-mime install --mode system "${TMPDIR}/newhouse-ptguimimetypes.xml"

xdg-desktop-menu install --mode system "${TMPDIR}/newhouse-ptgui.desktop"

xdg-desktop-menu install --mode system "${TMPDIR}/newhouse-ptguiviewer.desktop"

### The default option is for use inside a desktop session only. It is not recommended to use xdg-mime default as root. 
# xdg-mime default PTGui.desktop application-x-ptguiproject
# xdg-mime default PTGui.desktop application-x-ptguibatchlist

xdg-icon-resource install --mode system --context mimetypes --size 256 "${INSTALLDIR}/ptgui_icon.png" application-x-ptguiproject

xdg-icon-resource install --mode system --context mimetypes --size 256 "${INSTALLDIR}/ptgui_icon.png" application-x-ptguibatchlist

rm -rf "${TMPDIR}"

echo "${APPNAME} was installed succesfully!"

